@@ -1,11 +1,16 @@
-from os.path import basename, splitext
-from sys import argv, stderr, exc_info
+from importlib import import_module
+from os.path import basename, dirname, splitext
+from sys import argv, path, stderr, exc_info
 from traceback import extract_tb
 
+
 if __package__:
-    from .process.main import main
+    from .process import main
 else:
-    from process.main import main
+    package_parent_path = dirname(dirname(__file__))
+    package_name = basename(dirname(__file__))
+    path.insert(0, package_parent_path)
+    main = import_module(f"{package_name}.process", package_name).main
 
 
 def process_exc_trace(exc_trace):
